.. This file should at least contain the root `toctree` directive.

Welcome to Tarbell!
===================

Tarbell is a simple content management system that makes it easy to collaboratively
build and publish static websites. Tarbell is designed to help smart, technically
inclined people learn to build beautiful websites and publish them with ease.

Read the `Tarbell tutorial <tutorial.html>`_ to get started.

Tarbell is named after Ida Tarbell, a distinguished muckraking journalist whose
1904 The History of the Standard Oil Company is a masterpiece of investigative
reporting. `Read more about her on Wikipedia
<http://en.wikipedia.org/wiki/Ida_Tarbell>`_.

Need help? `Join the email list <https://groups.google.com/forum/#!forum/tarbell-project>`_.

Using Tarbell
=============

.. toctree::
   tutorial
   install
   create
   build
   publish
   managingprojects

Reference
=========

.. toctree::
    contributing
    base_templates
    reference
    configuring

